@@ -1,23 +1,20 @@
-extern crate glob;
-
-use glob::glob;
 use std::collections::HashSet;
 use std::env;
 use std::fs;
 use std::io::{self, BufRead, Write};
-use std::path;
+use std::path::{self, Path};
 
 fn get_crate_dir() -> io::Result<path::PathBuf> {
     Ok(path::PathBuf::from(
-        env::var("CARGO_MANIFEST_DIR").map_err(|_| {
-            io::Error::new(io::ErrorKind::Other, "no CARGO_MANIFEST_DIR")
-        })?,
+        env::var("CARGO_MANIFEST_DIR")
+            .map_err(|_| io::Error::new(io::ErrorKind::Other, "no CARGO_MANIFEST_DIR"))?,
     ))
 }
 
 fn get_out_dir() -> io::Result<path::PathBuf> {
-    Ok(path::PathBuf::from(env::var("OUT_DIR")
-        .map_err(|_| io::Error::new(io::ErrorKind::Other, "no OUT_DIR"))?))
+    Ok(path::PathBuf::from(env::var("OUT_DIR").map_err(|_| {
+        io::Error::new(io::ErrorKind::Other, "no OUT_DIR")
+    })?))
 }
 
 fn get_crate_test_path(file_name: &str) -> io::Result<path::PathBuf> {
@@ -59,24 +56,21 @@ use std::io::Read;
 "
     )?;
 
-    for entry in glob("./in/*").expect("should read glob pattern") {
-        if let Ok(path) = entry {
-            println!("cargo:rerun-if-changed={}", path.display());
-        }
-    }
     println!("cargo:rerun-if-changed=tests/afl_seeds.rs");
 
-
     let entries = fs::read_dir(in_dir)?;
 
     for entry in entries {
         let entry = entry?;
 
         let path = entry.path();
-        let file_name = path.file_name().ok_or(io::Error::new(
-            io::ErrorKind::Other,
-            "no file name for AFL.rs seed test case",
-        ))?;
+        let file_name = path.file_name().ok_or_else(|| {
+            io::Error::new(
+                io::ErrorKind::Other,
+                "no file name for AFL.rs seed test case",
+            )
+        })?;
+        println!("cargo:rerun-if-changed=in/{}", Path::new(file_name).display());
 
         writeln!(
             &mut test_file,
@@ -135,12 +129,11 @@ use std::fmt::Write;
         let mut s: HashSet<_> = (0..86).collect();
         s.extend(87..89);
         s.extend(91..93);
-        s.extend(94..105);
-        s.extend(106..113);
+        s.extend(94..113);
         s.extend(115..118);
         s.extend(119..120);
         s.extend(121..124);
-        s.extend(128..131);
+        s.extend(127..131);
         s.extend(133..134);
         s.extend(137..138);
         s.extend(139..140);
@@ -148,8 +141,7 @@ use std::fmt::Write;
         s.extend(146..147);
         s.extend(149..154);
         s.extend(158..168);
-        s.extend(169..175);
-        s.extend(177..180);
+        s.extend(169..180);
         s.extend(181..183);
         s.extend(184..186);
         s.extend(187..190);
@@ -163,9 +155,9 @@ use std::fmt::Write;
     let libiberty_tests = fs::File::open(libiberty_tests)?;
     let libiberty_tests = io::BufReader::new(libiberty_tests);
 
-    let mut lines = libiberty_tests.lines().filter(|line| {
-        line.as_ref().map(|l| !l.starts_with('#')).unwrap_or(true)
-    });
+    let mut lines = libiberty_tests
+        .lines()
+        .filter(|line| line.as_ref().map(|l| !l.starts_with('#')).unwrap_or(true));
 
     let mut n = 0;
 
@@ -215,7 +207,8 @@ use std::fmt::Write;
         }
 
         // Skip tests for unsupported languages or options.
-        if options.find("--format=gnu-v3").is_none() || options.find("--is-v3-ctor").is_some()
+        if options.find("--format=gnu-v3").is_none()
+            || options.find("--is-v3-ctor").is_some()
             || options.find("--is-v3-dtor").is_some()
             || options.find("--ret-postfix").is_some()
         {
